/* snapshot-list-row.c generated by valac 0.37.1.4-3591e, the Vala compiler
 * generated from snapshot-list-row.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <stdlib.h>
#include <string.h>
#include <cairo.h>
#include <gio/gio.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <float.h>
#include <math.h>
#include <gdk/gdk.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_SNAPSHOT_LIST_ROW (boxes_snapshot_list_row_get_type ())
#define BOXES_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow))
#define BOXES_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))
#define BOXES_IS_SNAPSHOT_LIST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_IS_SNAPSHOT_LIST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SNAPSHOT_LIST_ROW))
#define BOXES_SNAPSHOT_LIST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowClass))

typedef struct _BoxesSnapshotListRow BoxesSnapshotListRow;
typedef struct _BoxesSnapshotListRowClass BoxesSnapshotListRowClass;
typedef struct _BoxesSnapshotListRowPrivate BoxesSnapshotListRowPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
enum  {
	BOXES_SNAPSHOT_LIST_ROW_DUMMY_PROPERTY,
	BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE,
	BOXES_SNAPSHOT_LIST_ROW_LAST_PROPERTY
};
static GParamSpec* boxes_snapshot_list_row_properties[BOXES_SNAPSHOT_LIST_ROW_LAST_PROPERTY];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _Block107Data Block107Data;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_NOTIFICATION (boxes_notification_get_type ())
#define BOXES_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotification))
#define BOXES_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))
#define BOXES_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATION))
#define BOXES_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATION))
#define BOXES_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))

typedef struct _BoxesNotification BoxesNotification;
typedef struct _BoxesNotificationClass BoxesNotificationClass;
typedef struct _Block108Data Block108Data;
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

struct _BoxesSnapshotListRow {
	GtkListBoxRow parent_instance;
	BoxesSnapshotListRowPrivate * priv;
	GVirDomainSnapshot* snapshot;
};

struct _BoxesSnapshotListRowClass {
	GtkListBoxRowClass parent_class;
};

struct _BoxesSnapshotListRowPrivate {
	gchar* _activity_message;
	GtkLabel* name_label;
	GtkStack* mode_stack;
	GtkEntry* name_entry;
	GtkBox* edit_name_box;
	GtkBox* show_name_box;
	gint index;
	gint parent_size;
	BoxesLibvirtMachine* machine;
	GtkContainer* parent_container;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _Block107Data {
	int _ref_count_;
	BoxesSnapshotListRow* self;
	gulong restart_id;
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _Block108Data {
	int _ref_count_;
	BoxesSnapshotListRow* self;
	BoxesSnapshotListRow* row;
};

typedef void (*BoxesNotificationOKFunc) (void* user_data);
typedef void (*BoxesNotificationDismissFunc) (void* user_data);

static gpointer boxes_snapshot_list_row_parent_class = NULL;

GType boxes_snapshot_list_row_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
#define BOXES_SNAPSHOT_LIST_ROW_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRowPrivate))
static void boxes_snapshot_list_row_revert_to_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v);
static void _boxes_snapshot_list_row_revert_to_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_snapshot_list_row_rename_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v);
static void _boxes_snapshot_list_row_rename_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
static void boxes_snapshot_list_row_delete_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v);
static void _boxes_snapshot_list_row_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self);
BoxesSnapshotListRow* boxes_snapshot_list_row_new (GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
BoxesSnapshotListRow* boxes_snapshot_list_row_construct (GType object_type, GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine);
static gboolean boxes_snapshot_list_row_real_draw (GtkWidget* base, cairo_t* ct);
static void boxes_snapshot_list_row_on_save_name_button_clicked (BoxesSnapshotListRow* self);
static void _boxes_snapshot_list_row_on_save_name_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_snapshot_list_row_set_activity_message (BoxesSnapshotListRow* self, const gchar* value);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
BoxesAppWindow* boxes_machine_get_window (BoxesMachine* self);
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
BoxesUIState boxes_ui_get_previous_ui_state (BoxesUI* self);
static Block107Data* block107_data_ref (Block107Data* _data107_);
static void block107_data_unref (void * _userdata_);
GVirDomain* boxes_libvirt_machine_get_domain (BoxesLibvirtMachine* self);
static void ___lambda132_ (Block107Data* _data107_);
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
void boxes_libvirt_machine_start (BoxesLibvirtMachine* self, BoxesMachineConnectFlags flags, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_start_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static void ____lambda132__gvir_domain_stopped (GVirDomain* _sender, gpointer self);
static void __lambda133_ (BoxesSnapshotListRow* self, GObject* obj, GAsyncResult* res);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GType boxes_notification_get_type (void) G_GNUC_CONST;
BoxesNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void ___lambda133__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static Block108Data* block108_data_ref (Block108Data* _data108_);
static void block108_data_unref (void * _userdata_);
static void __lambda134_ (Block108Data* _data108_);
static void ___lambda134__boxes_notification_ok_func (gpointer self);
static void __lambda135_ (Block108Data* _data108_);
static void __lambda136_ (BoxesSnapshotListRow* self, GObject* obj, GAsyncResult* res);
static void ___lambda136__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void ___lambda135__boxes_notification_dismiss_func (gpointer self);
BoxesNotification* boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationDismissFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify, gint timeout);
static void boxes_snapshot_list_row_update_index (BoxesSnapshotListRow* self);
const gchar* boxes_snapshot_list_row_get_activity_message (BoxesSnapshotListRow* self);
static GObject * boxes_snapshot_list_row_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_snapshot_list_row___lambda137_ (BoxesSnapshotListRow* self);
static void _boxes_snapshot_list_row_update_index_gtk_container_add (GtkContainer* _sender, GtkWidget* widget, gpointer self);
static void _boxes_snapshot_list_row_update_index_gtk_container_remove (GtkContainer* _sender, GtkWidget* widget, gpointer self);
static void __boxes_snapshot_list_row___lambda137__gtk_widget_parent_set (GtkWidget* _sender, GtkWidget* previous_parent, gpointer self);
static void boxes_snapshot_list_row_finalize (GObject * obj);
static void _vala_boxes_snapshot_list_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_snapshot_list_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const GActionEntry BOXES_SNAPSHOT_LIST_ROW_action_entries[3] = {{"revert-to", _boxes_snapshot_list_row_revert_to_activated_gsimple_action_activate_callback}, {"rename", _boxes_snapshot_list_row_rename_activated_gsimple_action_activate_callback}, {"delete", _boxes_snapshot_list_row_delete_activated_gsimple_action_activate_callback}};

static void _boxes_snapshot_list_row_revert_to_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 26 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_revert_to_activated ((BoxesSnapshotListRow*) self, action, parameter);
#line 241 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_rename_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 26 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_rename_activated ((BoxesSnapshotListRow*) self, action, parameter);
#line 248 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_delete_activated_gsimple_action_activate_callback (GSimpleAction* action, GVariant* parameter, gpointer self) {
#line 26 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_delete_activated ((BoxesSnapshotListRow*) self, action, parameter);
#line 255 "snapshot-list-row.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 52 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return self ? g_object_ref (self) : NULL;
#line 262 "snapshot-list-row.c"
}


BoxesSnapshotListRow* boxes_snapshot_list_row_construct (GType object_type, GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine) {
	BoxesSnapshotListRow * self = NULL;
	GVirDomainSnapshot* _tmp0_;
	GVirDomainSnapshot* _tmp1_;
	BoxesLibvirtMachine* _tmp2_;
	BoxesLibvirtMachine* _tmp3_;
	GSimpleActionGroup* action_group = NULL;
	GSimpleActionGroup* _tmp13_;
	GError * _inner_error_ = NULL;
#line 50 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (snapshot != NULL, NULL);
#line 50 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (machine != NULL, NULL);
#line 50 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self = (BoxesSnapshotListRow*) g_object_new (object_type, NULL);
#line 52 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = snapshot;
#line 52 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 52 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->snapshot);
#line 52 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->snapshot = _tmp1_;
#line 53 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = machine;
#line 53 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 53 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->machine);
#line 53 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->machine = _tmp3_;
#line 297 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* _tmp4_ = NULL;
		GVirDomainSnapshot* _tmp5_;
		GVirConfigDomainSnapshot* _tmp6_;
		GtkLabel* _tmp7_;
		GVirConfigDomainSnapshot* _tmp8_;
		GVirConfigDomainSnapshot* _tmp9_;
		const gchar* _tmp10_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = snapshot;
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = gvir_domain_snapshot_get_config (_tmp5_, (guint) 0, &_inner_error_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = _tmp6_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 314 "snapshot-list-row.c"
			goto __catch149_g_error;
		}
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = self->priv->name_label;
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = _tmp4_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = NULL;
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = _tmp8_;
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = gvir_config_domain_snapshot_get_description (_tmp9_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gtk_label_set_label (_tmp7_, _tmp10_);
#line 56 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (_tmp9_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (_tmp4_);
#line 333 "snapshot-list-row.c"
	}
	goto __finally149;
	__catch149_g_error:
	{
		GError* e = NULL;
		GError* _tmp11_;
		const gchar* _tmp12_;
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 58 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = e;
#line 58 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp12_ = _tmp11_->message;
#line 58 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("snapshot-list-row.vala:58: %s", _tmp12_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 353 "snapshot-list-row.c"
	}
	__finally149:
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return NULL;
#line 364 "snapshot-list-row.c"
	}
#line 61 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp13_ = g_simple_action_group_new ();
#line 61 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	action_group = _tmp13_;
#line 62 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_action_map_add_action_entries ((GActionMap*) action_group, BOXES_SNAPSHOT_LIST_ROW_action_entries, G_N_ELEMENTS (BOXES_SNAPSHOT_LIST_ROW_action_entries), self);
#line 63 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_insert_action_group ((GtkWidget*) self, "snap", (GActionGroup*) action_group);
#line 50 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (action_group);
#line 50 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return self;
#line 378 "snapshot-list-row.c"
}


BoxesSnapshotListRow* boxes_snapshot_list_row_new (GVirDomainSnapshot* snapshot, BoxesLibvirtMachine* machine) {
#line 50 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return boxes_snapshot_list_row_construct (BOXES_TYPE_SNAPSHOT_LIST_ROW, snapshot, machine);
#line 385 "snapshot-list-row.c"
}


static gboolean boxes_snapshot_list_row_real_draw (GtkWidget* base, cairo_t* ct) {
	BoxesSnapshotListRow * self;
	gboolean result = FALSE;
	cairo_t* _tmp0_;
	gint height = 0;
	gint _tmp1_;
	GtkStyleContext* sc = NULL;
	GtkStyleContext* _tmp2_;
	GtkStyleContext* _tmp3_;
	gdouble indicator_size = 0.0;
	gint _tmp4_;
	GtkStyleContext* _tmp5_;
	GtkStyleContext* _tmp6_;
	GdkRGBA line_color = {0};
	GtkStyleContext* _tmp7_;
	GtkStateFlags _tmp8_;
	GdkRGBA _tmp9_ = {0};
	cairo_t* _tmp10_;
	GdkRGBA _tmp11_;
	gdouble _tmp12_;
	GdkRGBA _tmp13_;
	gdouble _tmp14_;
	GdkRGBA _tmp15_;
	gdouble _tmp16_;
	GdkRGBA _tmp17_;
	gdouble _tmp18_;
	cairo_t* _tmp19_;
	gint _tmp20_;
	gint _tmp27_;
	gint _tmp28_;
	gboolean is_current = FALSE;
	gboolean _tmp41_;
	cairo_t* _tmp43_;
	GtkStyleContext* _tmp44_;
	cairo_t* _tmp45_;
	gint _tmp46_;
	gint _tmp47_;
	gdouble _tmp48_;
	gdouble _tmp49_;
	GtkStyleContext* _tmp50_;
	cairo_t* _tmp51_;
	gint _tmp52_;
	gint _tmp53_;
	gdouble _tmp54_;
	gdouble _tmp55_;
	cairo_t* _tmp56_;
	GtkStyleContext* _tmp57_;
	GError * _inner_error_ = NULL;
#line 67 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self = (BoxesSnapshotListRow*) base;
#line 67 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (ct != NULL, FALSE);
#line 68 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = ct;
#line 68 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	GTK_WIDGET_CLASS (boxes_snapshot_list_row_parent_class)->draw ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, gtk_list_box_row_get_type (), GtkListBoxRow), _tmp0_);
#line 69 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gtk_widget_get_allocated_height ((GtkWidget*) self);
#line 69 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	height = _tmp1_;
#line 70 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 70 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 70 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	sc = _tmp3_;
#line 72 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = height;
#line 72 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	indicator_size = _tmp4_ / 2.0;
#line 74 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = sc;
#line 74 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_save (_tmp5_);
#line 75 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp6_ = sc;
#line 75 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_add_class (_tmp6_, "indicator");
#line 77 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp7_ = sc;
#line 77 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp8_ = gtk_widget_get_state_flags ((GtkWidget*) self);
#line 77 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_get_background_color (_tmp7_, _tmp8_, &_tmp9_);
#line 77 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	line_color = _tmp9_;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp10_ = ct;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp11_ = line_color;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp12_ = _tmp11_.red;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp13_ = line_color;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp14_ = _tmp13_.green;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp15_ = line_color;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp16_ = _tmp15_.blue;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp17_ = line_color;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp18_ = _tmp17_.alpha;
#line 78 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	cairo_set_source_rgba (_tmp10_, _tmp12_, _tmp14_, _tmp16_, _tmp18_);
#line 79 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp19_ = ct;
#line 79 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	cairo_set_line_width (_tmp19_, (gdouble) 4);
#line 80 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp20_ = self->priv->index;
#line 80 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp20_ > 0) {
#line 503 "snapshot-list-row.c"
		cairo_t* _tmp21_;
		gint _tmp22_;
		cairo_t* _tmp23_;
		gint _tmp24_;
		gint _tmp25_;
		cairo_t* _tmp26_;
#line 81 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp21_ = ct;
#line 81 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp22_ = height;
#line 81 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		cairo_move_to (_tmp21_, (_tmp22_ / 2.0) + 0.5, (gdouble) -1);
#line 82 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp23_ = ct;
#line 82 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp24_ = height;
#line 82 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp25_ = height;
#line 82 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		cairo_line_to (_tmp23_, (_tmp24_ / 2.0) + 0.5, _tmp25_ / 2.0);
#line 83 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp26_ = ct;
#line 83 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		cairo_stroke (_tmp26_);
#line 528 "snapshot-list-row.c"
	}
#line 85 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp27_ = self->priv->index;
#line 85 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp28_ = self->priv->parent_size;
#line 85 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp27_ < (_tmp28_ - 1)) {
#line 536 "snapshot-list-row.c"
		cairo_t* _tmp29_;
		gint _tmp30_;
		gint _tmp31_;
		cairo_t* _tmp32_;
		gint _tmp33_;
		gint _tmp34_;
		cairo_t* _tmp35_;
#line 86 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp29_ = ct;
#line 86 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp30_ = height;
#line 86 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp31_ = height;
#line 86 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		cairo_move_to (_tmp29_, (_tmp30_ / 2.0) + 0.5, _tmp31_ / 2.0);
#line 87 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp32_ = ct;
#line 87 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp33_ = height;
#line 87 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp34_ = height;
#line 87 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		cairo_line_to (_tmp32_, (_tmp33_ / 2.0) + 0.5, (gdouble) (_tmp34_ + 1));
#line 88 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp35_ = ct;
#line 88 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		cairo_stroke (_tmp35_);
#line 564 "snapshot-list-row.c"
	}
#line 91 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	is_current = FALSE;
#line 568 "snapshot-list-row.c"
	{
		GVirDomainSnapshot* _tmp36_;
		gboolean _tmp37_ = FALSE;
#line 93 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp36_ = self->snapshot;
#line 93 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_get_is_current (_tmp36_, (guint) 0, &_tmp37_, &_inner_error_);
#line 93 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		is_current = _tmp37_;
#line 93 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 580 "snapshot-list-row.c"
			goto __catch150_g_error;
		}
	}
	goto __finally150;
	__catch150_g_error:
	{
		GError* e = NULL;
		GError* _tmp38_;
		const gchar* _tmp39_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 95 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp38_ = e;
#line 95 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp39_ = _tmp38_->message;
#line 95 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:95: %s", _tmp39_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 602 "snapshot-list-row.c"
	}
	__finally150:
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 607 "snapshot-list-row.c"
		gboolean _tmp40_ = FALSE;
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (sc);
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 92 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return _tmp40_;
#line 617 "snapshot-list-row.c"
	}
#line 98 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp41_ = is_current;
#line 98 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp41_) {
#line 623 "snapshot-list-row.c"
		GtkStyleContext* _tmp42_;
#line 99 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp42_ = sc;
#line 99 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gtk_style_context_add_class (_tmp42_, "active");
#line 629 "snapshot-list-row.c"
	}
#line 101 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp43_ = ct;
#line 101 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	cairo_save (_tmp43_);
#line 102 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp44_ = sc;
#line 102 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp45_ = ct;
#line 102 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp46_ = height;
#line 102 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp47_ = height;
#line 102 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp48_ = indicator_size;
#line 102 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp49_ = indicator_size;
#line 102 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_render_background (_tmp44_, _tmp45_, _tmp46_ / 4.0, _tmp47_ / 4.0, _tmp48_, _tmp49_);
#line 103 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp50_ = sc;
#line 103 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp51_ = ct;
#line 103 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp52_ = height;
#line 103 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp53_ = height;
#line 103 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp54_ = indicator_size;
#line 103 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp55_ = indicator_size;
#line 103 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_render_frame (_tmp50_, _tmp51_, _tmp52_ / 4.0, _tmp53_ / 4.0, _tmp54_, _tmp55_ + 0.5);
#line 104 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp56_ = ct;
#line 104 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	cairo_restore (_tmp56_);
#line 106 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp57_ = sc;
#line 106 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_restore (_tmp57_);
#line 108 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	result = TRUE;
#line 108 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (sc);
#line 108 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return result;
#line 677 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_on_save_name_button_clicked (BoxesSnapshotListRow* self) {
	gchar* name = NULL;
	GtkEntry* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 112 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 113 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->name_entry;
#line 113 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 113 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = _tmp1_;
#line 113 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 113 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	name = _tmp3_;
#line 700 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* config = NULL;
		GVirDomainSnapshot* _tmp4_;
		GVirConfigDomainSnapshot* _tmp5_;
		GVirConfigDomainSnapshot* _tmp6_;
		const gchar* _tmp7_;
		GVirDomainSnapshot* _tmp8_;
		GVirConfigDomainSnapshot* _tmp9_;
		GtkLabel* _tmp10_;
		const gchar* _tmp11_;
		GtkStack* _tmp12_;
		GtkBox* _tmp13_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = self->snapshot;
#line 116 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = gvir_domain_snapshot_get_config (_tmp4_, (guint) 0, &_inner_error_);
#line 116 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		config = _tmp5_;
#line 116 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 721 "snapshot-list-row.c"
			goto __catch151_g_error;
		}
#line 117 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = config;
#line 117 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = name;
#line 117 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gvir_config_domain_snapshot_set_description (_tmp6_, _tmp7_);
#line 118 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = self->snapshot;
#line 118 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = config;
#line 118 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_set_config (_tmp8_, _tmp9_, &_inner_error_);
#line 118 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 118 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
			_g_object_unref0 (config);
#line 740 "snapshot-list-row.c"
			goto __catch151_g_error;
		}
#line 119 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = self->priv->name_label;
#line 119 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = name;
#line 119 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gtk_label_set_label (_tmp10_, _tmp11_);
#line 120 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp12_ = self->priv->mode_stack;
#line 120 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp13_ = self->priv->show_name_box;
#line 120 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gtk_stack_set_visible_child (_tmp12_, (GtkWidget*) _tmp13_);
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (config);
#line 757 "snapshot-list-row.c"
	}
	goto __finally151;
	__catch151_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp14_;
		GError* _tmp15_;
		const gchar* _tmp16_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 122 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp14_ = name;
#line 122 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp15_ = e;
#line 122 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp16_ = _tmp15_->message;
#line 122 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:122: Failed to change name of snapshot to %s: %" \
"s", _tmp14_, _tmp16_);
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 780 "snapshot-list-row.c"
	}
	__finally151:
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (name);
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 115 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 793 "snapshot-list-row.c"
	}
#line 112 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (name);
#line 797 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_on_save_name_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_on_save_name_button_clicked ((BoxesSnapshotListRow*) self);
#line 804 "snapshot-list-row.c"
}


static Block107Data* block107_data_ref (Block107Data* _data107_) {
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_atomic_int_inc (&_data107_->_ref_count_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return _data107_;
#line 813 "snapshot-list-row.c"
}


static void block107_data_unref (void * _userdata_) {
	Block107Data* _data107_;
	_data107_ = (Block107Data*) _userdata_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (g_atomic_int_dec_and_test (&_data107_->_ref_count_)) {
#line 822 "snapshot-list-row.c"
		BoxesSnapshotListRow* self;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		self = _data107_->self;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (self);
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_slice_free (Block107Data, _data107_);
#line 830 "snapshot-list-row.c"
	}
}


static void ___lambda132_ (Block107Data* _data107_) {
	BoxesSnapshotListRow* self;
	BoxesLibvirtMachine* _tmp0_;
	BoxesLibvirtMachine* _tmp1_;
	GVirDomain* _tmp2_;
	GVirDomain* _tmp3_;
	gulong _tmp4_;
#line 143 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self = _data107_->self;
#line 144 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->machine;
#line 144 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_libvirt_machine_start (_tmp0_, BOXES_MACHINE_CONNECT_FLAGS_NONE, NULL, NULL, NULL);
#line 145 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = self->priv->machine;
#line 145 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = boxes_libvirt_machine_get_domain (_tmp1_);
#line 145 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = _tmp2_;
#line 145 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = _data107_->restart_id;
#line 145 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 858 "snapshot-list-row.c"
}


static void ____lambda132__gvir_domain_stopped (GVirDomain* _sender, gpointer self) {
#line 143 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	___lambda132_ (self);
#line 865 "snapshot-list-row.c"
}


static void __lambda133_ (BoxesSnapshotListRow* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 149 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (res != NULL);
#line 873 "snapshot-list-row.c"
	{
		GVirDomainSnapshot* _tmp0_;
		GAsyncResult* _tmp1_;
		GtkContainer* _tmp2_;
#line 151 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp0_ = self->snapshot;
#line 151 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp1_ = res;
#line 151 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_revert_to_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 151 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 886 "snapshot-list-row.c"
			goto __catch153_g_error;
		}
#line 152 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = self->priv->parent_container;
#line 152 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gtk_widget_queue_draw ((GtkWidget*) _tmp2_);
#line 893 "snapshot-list-row.c"
	}
	goto __finally153;
	__catch153_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		BoxesLibvirtMachine* _tmp5_;
		BoxesAppWindow* _tmp6_;
		BoxesAppWindow* _tmp7_;
		BoxesNotificationbar* _tmp8_;
		BoxesNotificationbar* _tmp9_;
		BoxesNotification* _tmp10_;
		BoxesNotification* _tmp11_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 154 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = e;
#line 154 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = _tmp3_->message;
#line 154 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:154: %s", _tmp4_);
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = self->priv->machine;
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = boxes_machine_get_window ((BoxesMachine*) _tmp5_);
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = _tmp6_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = boxes_app_window_get_notificationbar (_tmp7_);
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = _tmp8_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = boxes_notificationbar_display_error (_tmp9_, _ ("Failed to apply snapshot"), BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = _tmp10_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (_tmp11_);
#line 150 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 936 "snapshot-list-row.c"
	}
	__finally153:
#line 150 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 150 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 150 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 150 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 947 "snapshot-list-row.c"
	}
#line 157 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_set_activity_message (self, NULL);
#line 951 "snapshot-list-row.c"
}


static void ___lambda133__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 149 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	__lambda133_ ((BoxesSnapshotListRow*) self, source_object, res);
#line 149 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_object_unref (self);
#line 960 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_revert_to_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v) {
	gchar* snapshot_name = NULL;
	GVirDomainSnapshot* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	GVirConfigDomainSnapshotDomainState snapshot_state = 0;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gboolean _tmp11_ = FALSE;
	BoxesLibvirtMachine* _tmp12_;
	BoxesAppWindow* _tmp13_;
	BoxesAppWindow* _tmp14_;
	BoxesUIState _tmp15_;
	BoxesUIState _tmp16_;
	GVirDomainSnapshot* _tmp22_;
	GError * _inner_error_ = NULL;
#line 127 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 127 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (action != NULL);
#line 128 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->snapshot;
#line 128 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gvir_domain_snapshot_get_name (_tmp0_);
#line 128 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 128 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	snapshot_name = _tmp2_;
#line 129 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	snapshot_state = GVIR_CONFIG_DOMAIN_SNAPSHOT_DOMAIN_STATE_NOSTATE;
#line 995 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* snapshot_config = NULL;
		GVirDomainSnapshot* _tmp3_;
		GVirConfigDomainSnapshot* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		GVirConfigDomainSnapshotDomainState _tmp7_;
#line 132 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = self->snapshot;
#line 132 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = gvir_domain_snapshot_get_config (_tmp3_, (guint) 0, &_inner_error_);
#line 132 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_config = _tmp4_;
#line 132 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1011 "snapshot-list-row.c"
			goto __catch152_g_error;
		}
#line 133 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = gvir_config_domain_snapshot_get_description (snapshot_config);
#line 133 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 133 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_name);
#line 133 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_name = _tmp6_;
#line 134 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = gvir_config_domain_snapshot_get_state (snapshot_config);
#line 134 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_state = _tmp7_;
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (snapshot_config);
#line 1028 "snapshot-list-row.c"
	}
	goto __finally152;
	__catch152_g_error:
	{
		GError* e = NULL;
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 1040 "snapshot-list-row.c"
	}
	__finally152:
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_name);
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 131 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1053 "snapshot-list-row.c"
	}
#line 137 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp8_ = snapshot_name;
#line 137 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp9_ = g_strdup_printf (_ ("Reverting to %s…"), _tmp8_);
#line 137 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp10_ = _tmp9_;
#line 137 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_set_activity_message (self, _tmp10_);
#line 137 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (_tmp10_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp12_ = self->priv->machine;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp13_ = boxes_machine_get_window ((BoxesMachine*) _tmp12_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp14_ = _tmp13_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp15_ = boxes_ui_get_previous_ui_state ((BoxesUI*) _tmp14_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp16_ = _tmp15_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp16_ == BOXES_UI_STATE_DISPLAY) {
#line 1077 "snapshot-list-row.c"
		GVirConfigDomainSnapshotDomainState _tmp17_;
#line 140 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp17_ = snapshot_state;
#line 140 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = _tmp17_ == GVIR_CONFIG_DOMAIN_SNAPSHOT_DOMAIN_STATE_SHUTOFF;
#line 1083 "snapshot-list-row.c"
	} else {
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp11_ = FALSE;
#line 1087 "snapshot-list-row.c"
	}
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp11_) {
#line 1091 "snapshot-list-row.c"
		Block107Data* _data107_;
		BoxesLibvirtMachine* _tmp18_;
		GVirDomain* _tmp19_;
		GVirDomain* _tmp20_;
		gulong _tmp21_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_data107_ = g_slice_new0 (Block107Data);
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_data107_->_ref_count_ = 1;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_data107_->self = g_object_ref (self);
#line 142 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_data107_->restart_id = (gulong) 0;
#line 143 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp18_ = self->priv->machine;
#line 143 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp19_ = boxes_libvirt_machine_get_domain (_tmp18_);
#line 143 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp20_ = _tmp19_;
#line 143 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp21_ = g_signal_connect_data (_tmp20_, "stopped", (GCallback) ____lambda132__gvir_domain_stopped, block107_data_ref (_data107_), (GClosureNotify) block107_data_unref, 0);
#line 143 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_data107_->restart_id = _tmp21_;
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		block107_data_unref (_data107_);
#line 139 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_data107_ = NULL;
#line 1119 "snapshot-list-row.c"
	}
#line 149 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp22_ = self->snapshot;
#line 149 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gvir_domain_snapshot_revert_to_async (_tmp22_, (guint) 0, NULL, ___lambda133__gasync_ready_callback, g_object_ref (self));
#line 127 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (snapshot_name);
#line 1127 "snapshot-list-row.c"
}


static Block108Data* block108_data_ref (Block108Data* _data108_) {
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_atomic_int_inc (&_data108_->_ref_count_);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return _data108_;
#line 1136 "snapshot-list-row.c"
}


static void block108_data_unref (void * _userdata_) {
	Block108Data* _data108_;
	_data108_ = (Block108Data*) _userdata_;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (g_atomic_int_dec_and_test (&_data108_->_ref_count_)) {
#line 1145 "snapshot-list-row.c"
		BoxesSnapshotListRow* self;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		self = _data108_->self;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (_data108_->row);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (self);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_slice_free (Block108Data, _data108_);
#line 1155 "snapshot-list-row.c"
	}
}


static void __lambda134_ (Block108Data* _data108_) {
	BoxesSnapshotListRow* self;
	GtkContainer* _tmp0_;
#line 177 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self = _data108_->self;
#line 178 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->parent_container;
#line 178 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_container_add (_tmp0_, (GtkWidget*) self);
#line 179 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (_data108_->row);
#line 179 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_data108_->row = NULL;
#line 1173 "snapshot-list-row.c"
}


static void ___lambda134__boxes_notification_ok_func (gpointer self) {
#line 177 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	__lambda134_ (self);
#line 1180 "snapshot-list-row.c"
}


static void __lambda136_ (BoxesSnapshotListRow* self, GObject* obj, GAsyncResult* res) {
	GError * _inner_error_ = NULL;
#line 183 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (res != NULL);
#line 1188 "snapshot-list-row.c"
	{
		GVirDomainSnapshot* _tmp0_;
		GAsyncResult* _tmp1_;
		GtkContainer* _tmp2_;
#line 185 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp0_ = self->snapshot;
#line 185 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp1_ = res;
#line 185 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gvir_domain_snapshot_delete_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 185 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1201 "snapshot-list-row.c"
			goto __catch155_g_error;
		}
#line 186 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = self->priv->parent_container;
#line 186 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		gtk_widget_queue_draw ((GtkWidget*) _tmp2_);
#line 1208 "snapshot-list-row.c"
	}
	goto __finally155;
	__catch155_g_error:
	{
		GError* e = NULL;
		GVirDomainSnapshot* _tmp3_;
		const gchar* _tmp4_;
		GError* _tmp5_;
		const gchar* _tmp6_;
#line 184 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 184 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 188 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = self->snapshot;
#line 188 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = gvir_domain_snapshot_get_name (_tmp3_);
#line 188 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = e;
#line 188 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = _tmp5_->message;
#line 188 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:188: Error while deleting snapshot %s: %s", _tmp4_, _tmp6_);
#line 184 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 1234 "snapshot-list-row.c"
	}
	__finally155:
#line 184 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 184 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1245 "snapshot-list-row.c"
	}
}


static void ___lambda136__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 183 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	__lambda136_ ((BoxesSnapshotListRow*) self, source_object, res);
#line 183 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_object_unref (self);
#line 1255 "snapshot-list-row.c"
}


static void __lambda135_ (Block108Data* _data108_) {
	BoxesSnapshotListRow* self;
	GVirDomainSnapshot* _tmp0_;
#line 182 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self = _data108_->self;
#line 183 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->snapshot;
#line 183 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gvir_domain_snapshot_delete_async (_tmp0_, (guint) 0, NULL, ___lambda136__gasync_ready_callback, g_object_ref (self));
#line 191 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (_data108_->row);
#line 191 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_data108_->row = NULL;
#line 1272 "snapshot-list-row.c"
}


static void ___lambda135__boxes_notification_dismiss_func (gpointer self) {
#line 182 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	__lambda135_ (self);
#line 1279 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_delete_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v) {
	Block108Data* _data108_;
	gchar* snapshot_identifier = NULL;
	GVirDomainSnapshot* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* message = NULL;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	GtkContainer* _tmp13_;
	BoxesSnapshotListRow* _tmp14_;
	GtkContainer* _tmp15_;
	BoxesNotificationOKFunc undo = NULL;
	void* undo_target;
	GDestroyNotify undo_target_destroy_notify;
	BoxesNotificationDismissFunc really_remove = NULL;
	void* really_remove_target;
	GDestroyNotify really_remove_target_destroy_notify;
	BoxesLibvirtMachine* _tmp16_;
	BoxesAppWindow* _tmp17_;
	BoxesAppWindow* _tmp18_;
	BoxesNotificationbar* _tmp19_;
	BoxesNotificationbar* _tmp20_;
	BoxesNotificationOKFunc _tmp21_;
	void* _tmp21__target;
	GDestroyNotify _tmp21__target_destroy_notify;
	BoxesNotificationDismissFunc _tmp22_;
	void* _tmp22__target;
	GDestroyNotify _tmp22__target_destroy_notify;
	BoxesNotification* _tmp23_;
	BoxesNotification* _tmp24_;
	GError * _inner_error_ = NULL;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (action != NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_data108_ = g_slice_new0 (Block108Data);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_data108_->_ref_count_ = 1;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_data108_->self = g_object_ref (self);
#line 163 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->snapshot;
#line 163 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = gvir_domain_snapshot_get_name (_tmp0_);
#line 163 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 163 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	snapshot_identifier = _tmp2_;
#line 1333 "snapshot-list-row.c"
	{
		GVirConfigDomainSnapshot* config = NULL;
		GVirDomainSnapshot* _tmp3_;
		GVirConfigDomainSnapshot* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
#line 165 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp3_ = self->snapshot;
#line 165 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = gvir_domain_snapshot_get_config (_tmp3_, (guint) 0, &_inner_error_);
#line 165 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		config = _tmp4_;
#line 165 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1348 "snapshot-list-row.c"
			goto __catch154_g_error;
		}
#line 166 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp5_ = gvir_config_domain_snapshot_get_description (config);
#line 166 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 166 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_identifier);
#line 166 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		snapshot_identifier = _tmp6_;
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (config);
#line 1361 "snapshot-list-row.c"
	}
	goto __finally154;
	__catch154_g_error:
	{
		GError* e = NULL;
		GVirDomainSnapshot* _tmp7_;
		const gchar* _tmp8_;
		GError* _tmp9_;
		const gchar* _tmp10_;
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		e = _inner_error_;
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_inner_error_ = NULL;
#line 168 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp7_ = self->snapshot;
#line 168 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp8_ = gvir_domain_snapshot_get_name (_tmp7_);
#line 168 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp9_ = e;
#line 168 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp10_ = _tmp9_->message;
#line 168 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_warning ("snapshot-list-row.vala:168: Could not get configuration of snapshot %s" \
": %s", _tmp8_, _tmp10_);
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_error_free0 (e);
#line 1387 "snapshot-list-row.c"
	}
	__finally154:
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (snapshot_identifier);
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		block108_data_unref (_data108_);
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_data108_ = NULL;
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_clear_error (&_inner_error_);
#line 164 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1404 "snapshot-list-row.c"
	}
#line 172 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp11_ = snapshot_identifier;
#line 172 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp12_ = g_strdup_printf (_ ("Snapshot “%s” deleted."), _tmp11_);
#line 172 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	message = _tmp12_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp13_ = (GtkContainer*) gtk_widget_get_parent ((GtkWidget*) self);
#line 173 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->parent_container = G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, gtk_container_get_type (), GtkContainer);
#line 174 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp14_ = _g_object_ref0 (self);
#line 174 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_data108_->row = _tmp14_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp15_ = self->priv->parent_container;
#line 175 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_container_remove (_tmp15_, (GtkWidget*) self);
#line 177 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo = ___lambda134__boxes_notification_ok_func;
#line 177 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo_target = block108_data_ref (_data108_);
#line 177 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo_target_destroy_notify = block108_data_unref;
#line 182 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove = ___lambda135__boxes_notification_dismiss_func;
#line 182 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target = block108_data_ref (_data108_);
#line 182 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target_destroy_notify = block108_data_unref;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp16_ = self->priv->machine;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp17_ = boxes_machine_get_window ((BoxesMachine*) _tmp16_);
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp18_ = _tmp17_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp19_ = boxes_app_window_get_notificationbar (_tmp18_);
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp20_ = _tmp19_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp21_ = undo;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp21__target = undo_target;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp21__target_destroy_notify = undo_target_destroy_notify;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo = NULL;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo_target = NULL;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo_target_destroy_notify = NULL;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp22_ = really_remove;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp22__target = really_remove_target;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp22__target_destroy_notify = really_remove_target_destroy_notify;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove = NULL;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target = NULL;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target_destroy_notify = NULL;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp23_ = boxes_notificationbar_display_for_action (_tmp20_, message, _ ("_Undo"), _tmp21_, _tmp21__target, _tmp21__target_destroy_notify, _tmp22_, _tmp22__target, _tmp22__target_destroy_notify, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp24_ = _tmp23_;
#line 193 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (_tmp24_);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	(really_remove_target_destroy_notify == NULL) ? NULL : (really_remove_target_destroy_notify (really_remove_target), NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove = NULL;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target = NULL;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	really_remove_target_destroy_notify = NULL;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	(undo_target_destroy_notify == NULL) ? NULL : (undo_target_destroy_notify (undo_target), NULL);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo = NULL;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo_target = NULL;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	undo_target_destroy_notify = NULL;
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (message);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (snapshot_identifier);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	block108_data_unref (_data108_);
#line 162 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_data108_ = NULL;
#line 1500 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_rename_activated (BoxesSnapshotListRow* self, GSimpleAction* action, GVariant* v) {
	GtkEntry* _tmp0_;
	GtkLabel* _tmp1_;
	const gchar* _tmp2_;
	GtkStack* _tmp3_;
	GtkBox* _tmp4_;
	GtkEntry* _tmp5_;
#line 199 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 199 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (action != NULL);
#line 200 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->name_entry;
#line 200 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = self->priv->name_label;
#line 200 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = gtk_label_get_text (_tmp1_);
#line 200 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_entry_set_text (_tmp0_, _tmp2_);
#line 201 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = self->priv->mode_stack;
#line 201 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = self->priv->edit_name_box;
#line 201 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_stack_set_visible_child (_tmp3_, (GtkWidget*) _tmp4_);
#line 202 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = self->priv->name_entry;
#line 202 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp5_);
#line 1533 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_update_index (BoxesSnapshotListRow* self) {
	GtkContainer* parent = NULL;
	GtkContainer* _tmp0_;
	GtkContainer* _tmp1_;
	gboolean _tmp2_ = FALSE;
	GtkContainer* _tmp3_;
	GList* siblings = NULL;
	GtkContainer* _tmp5_;
	GList* _tmp6_;
	GList* _tmp7_;
	gint _tmp8_;
	GList* _tmp9_;
	guint _tmp10_;
#line 205 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 206 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = (GtkContainer*) gtk_widget_get_parent ((GtkWidget*) self);
#line 206 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 206 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	parent = _tmp1_;
#line 208 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = parent;
#line 208 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp3_ == NULL) {
#line 208 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = TRUE;
#line 1564 "snapshot-list-row.c"
	} else {
		GtkContainer* _tmp4_;
#line 208 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp4_ = parent;
#line 208 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp2_ = !G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gtk_list_box_get_type ());
#line 1571 "snapshot-list-row.c"
	}
#line 208 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp2_) {
#line 209 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (parent);
#line 209 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1579 "snapshot-list-row.c"
	}
#line 211 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = parent;
#line 211 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp6_ = gtk_container_get_children (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp5_) : NULL);
#line 211 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	siblings = _tmp6_;
#line 212 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp7_ = siblings;
#line 212 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp8_ = g_list_index (_tmp7_, (GtkWidget*) self);
#line 212 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->index = _tmp8_;
#line 213 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp9_ = siblings;
#line 213 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp10_ = g_list_length (_tmp9_);
#line 213 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->parent_size = (gint) _tmp10_;
#line 205 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_list_free0 (siblings);
#line 205 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (parent);
#line 1603 "snapshot-list-row.c"
}


const gchar* boxes_snapshot_list_row_get_activity_message (BoxesSnapshotListRow* self) {
	const gchar* result;
	const gchar* _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = self->priv->_activity_message;
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	result = _tmp0_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return result;
#line 1618 "snapshot-list-row.c"
}


void boxes_snapshot_list_row_set_activity_message (BoxesSnapshotListRow* self, const gchar* value) {
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_return_if_fail (self != NULL);
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (g_strcmp0 (value, boxes_snapshot_list_row_get_activity_message (self)) != 0) {
#line 1627 "snapshot-list-row.c"
		const gchar* _tmp0_;
		gchar* _tmp1_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp0_ = value;
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_free0 (self->priv->_activity_message);
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		self->priv->_activity_message = _tmp1_;
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_object_notify_by_pspec ((GObject *) self, boxes_snapshot_list_row_properties[BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE]);
#line 1640 "snapshot-list-row.c"
	}
}


static void _boxes_snapshot_list_row_update_index_gtk_container_add (GtkContainer* _sender, GtkWidget* widget, gpointer self) {
#line 42 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_update_index ((BoxesSnapshotListRow*) self);
#line 1648 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row_update_index_gtk_container_remove (GtkContainer* _sender, GtkWidget* widget, gpointer self) {
#line 43 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_update_index ((BoxesSnapshotListRow*) self);
#line 1655 "snapshot-list-row.c"
}


static void _boxes_snapshot_list_row___lambda137_ (BoxesSnapshotListRow* self) {
	GtkContainer* parent = NULL;
	GtkContainer* _tmp0_;
	GtkContainer* _tmp1_;
	GtkContainer* _tmp2_;
	GtkContainer* _tmp3_;
	GtkContainer* _tmp4_;
	GtkContainer* _tmp5_;
#line 35 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = (GtkContainer*) gtk_widget_get_parent ((GtkWidget*) self);
#line 35 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, gtk_container_get_type ()) ? ((GtkContainer*) _tmp0_) : NULL);
#line 35 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	parent = _tmp1_;
#line 37 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp2_ = parent;
#line 37 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	if (_tmp2_ == NULL) {
#line 38 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		_g_object_unref0 (parent);
#line 38 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		return;
#line 1681 "snapshot-list-row.c"
	}
#line 40 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp3_ = parent;
#line 40 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->parent_container = _tmp3_;
#line 41 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_update_index (self);
#line 42 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp4_ = parent;
#line 42 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_connect_object (_tmp4_, "add", (GCallback) _boxes_snapshot_list_row_update_index_gtk_container_add, self, 0);
#line 43 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp5_ = parent;
#line 43 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_connect_object (_tmp5_, "remove", (GCallback) _boxes_snapshot_list_row_update_index_gtk_container_remove, self, 0);
#line 34 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (parent);
#line 1699 "snapshot-list-row.c"
}


static void __boxes_snapshot_list_row___lambda137__gtk_widget_parent_set (GtkWidget* _sender, GtkWidget* previous_parent, gpointer self) {
#line 34 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_boxes_snapshot_list_row___lambda137_ ((BoxesSnapshotListRow*) self);
#line 1706 "snapshot-list-row.c"
}


static GObject * boxes_snapshot_list_row_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSnapshotListRow * self;
	GtkStyleContext* _tmp0_;
#line 32 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	parent_class = G_OBJECT_CLASS (boxes_snapshot_list_row_parent_class);
#line 32 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 32 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 33 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 33 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_style_context_add_class (_tmp0_, "boxes-snapshot-list-row");
#line 34 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_signal_connect_object ((GtkWidget*) self, "parent-set", (GCallback) __boxes_snapshot_list_row___lambda137__gtk_widget_parent_set, self, 0);
#line 45 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_list_box_row_set_selectable ((GtkListBoxRow*) self, FALSE);
#line 46 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, FALSE);
#line 32 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	return obj;
#line 1733 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_class_init (BoxesSnapshotListRowClass * klass) {
	gint BoxesSnapshotListRow_private_offset;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	boxes_snapshot_list_row_parent_class = g_type_class_peek_parent (klass);
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_type_class_add_private (klass, sizeof (BoxesSnapshotListRowPrivate));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	((GtkWidgetClass *) klass)->draw = (gboolean (*) (GtkWidget *, cairo_t*)) boxes_snapshot_list_row_real_draw;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_snapshot_list_row_get_property;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_snapshot_list_row_set_property;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_snapshot_list_row_constructor;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_snapshot_list_row_finalize;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE, boxes_snapshot_list_row_properties[BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE] = g_param_spec_string ("activity-message", "activity-message", "activity-message", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	BoxesSnapshotListRow_private_offset = g_type_class_get_instance_private_offset (klass);
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/snapshot-list-row.ui");
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "name_label", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, name_label));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "mode_stack", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, mode_stack));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "name_entry", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, name_entry));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "edit_name_box", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, edit_name_box));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "show_name_box", FALSE, BoxesSnapshotListRow_private_offset + G_STRUCT_OFFSET (BoxesSnapshotListRowPrivate, show_name_box));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_save_name_button_clicked", G_CALLBACK(_boxes_snapshot_list_row_on_save_name_button_clicked_gtk_button_clicked));
#line 1771 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_instance_init (BoxesSnapshotListRow * self) {
	gchar* _tmp0_;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv = BOXES_SNAPSHOT_LIST_ROW_GET_PRIVATE (self);
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_tmp0_ = g_strdup ("");
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->_activity_message = _tmp0_;
#line 24 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self->priv->parent_container = NULL;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1787 "snapshot-list-row.c"
}


static void boxes_snapshot_list_row_finalize (GObject * obj) {
	BoxesSnapshotListRow * self;
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 5 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->snapshot);
#line 6 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_free0 (self->priv->_activity_message);
#line 9 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->name_label);
#line 11 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->mode_stack);
#line 13 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->name_entry);
#line 15 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->edit_name_box);
#line 17 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->show_name_box);
#line 23 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	_g_object_unref0 (self->priv->machine);
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	G_OBJECT_CLASS (boxes_snapshot_list_row_parent_class)->finalize (obj);
#line 1813 "snapshot-list-row.c"
}


GType boxes_snapshot_list_row_get_type (void) {
	static volatile gsize boxes_snapshot_list_row_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_snapshot_list_row_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSnapshotListRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_snapshot_list_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSnapshotListRow), 0, (GInstanceInitFunc) boxes_snapshot_list_row_instance_init, NULL };
		GType boxes_snapshot_list_row_type_id;
		boxes_snapshot_list_row_type_id = g_type_register_static (gtk_list_box_row_get_type (), "BoxesSnapshotListRow", &g_define_type_info, 0);
		g_once_init_leave (&boxes_snapshot_list_row_type_id__volatile, boxes_snapshot_list_row_type_id);
	}
	return boxes_snapshot_list_row_type_id__volatile;
}


static void _vala_boxes_snapshot_list_row_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesSnapshotListRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	switch (property_id) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		case BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE:
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		g_value_set_string (value, boxes_snapshot_list_row_get_activity_message (self));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 1840 "snapshot-list-row.c"
		default:
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 1846 "snapshot-list-row.c"
	}
}


static void _vala_boxes_snapshot_list_row_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesSnapshotListRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_SNAPSHOT_LIST_ROW, BoxesSnapshotListRow);
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
	switch (property_id) {
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		case BOXES_SNAPSHOT_LIST_ROW_ACTIVITY_MESSAGE:
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		boxes_snapshot_list_row_set_activity_message (self, g_value_get_string (value));
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 1862 "snapshot-list-row.c"
		default:
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 4 "/home/fborges/checkout/gnome-boxes/src/snapshot-list-row.vala"
		break;
#line 1868 "snapshot-list-row.c"
	}
}



